In a Chrome extension, when you send a message using `chrome.runtime.sendMessage`, you could provide a callback function to handle the response returned by `sendResponse`. We chose not to provide the callback at popup.js:
- Ours at popup.js: `chrome.runtime.sendMessage({ type: 'activeTab', tabId: tabs[0].id, href });`
- But if we were handling a response back, we would have added a callback:
```
chrome.runtime.sendMessage({ type: 'activeTab', tabId: tabs[0].id, href }, (response) => {
  console.log("Got response:", response.reply); // "hello back!"
});
```

Our background.js did not send back a response although it always could have. See this line has a third parameter `sendResponse` at background.js: `chrome.runtime.onMessage.addListener(async function (request, sender, sendResponse)`. If we were to fully leverage that, we would have called using the sendResponse: `sendResponse({ reply: "hello back!" });` in the body of the event listener.

Example Background (receiver) side:

```js
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
  if (message.greeting === "hello") {
    console.log("Received message from sender:", sender); // logs sender object
    sendResponse({ reply: "hello back!" }); // Responds to sender
  }
  return true; // Needed if you want to respond asynchronously
});
```

> [!note] ^ Sender?
> That has Chrome extension and messaging general information:
> ```
> {
>   tab: {
>     id: 123,
>     url: "https://example.com",
>     // more tab details
>   },
>   id: "abcdefghijklmnopabcdefghijklmnop", // extension ID
>   origin: "https://example.com",
>   frameId: 0,
>   url: "https://example.com"
> }
> ```
> 

Example Sender side (like in content script, popup, or another part of your extension):
```js
chrome.runtime.sendMessage({ greeting: "hello" }, (response) => {
  console.log("Got response:", response.reply); // "hello back!"
});
```

So sendMessage can be bidirectional.